==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm5/lib/igc-geographic-scatter-area-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcColorScaleComponent } from "igniteui-webcomponents-charts";
import { IgcTriangulationStatusEventArgs } from "igniteui-webcomponents-core";
import { IgcGeographicXYTriangulatingSeriesComponent } from "./igc-geographic-xy-triangulating-series-component";
import { GeographicScatterAreaSeries } from "./GeographicScatterAreaSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class which draws a colored 2D surface, in a geographic context, based on a triangulation of XY data with numeric values assigned to each point.
*/
var IgcGeographicScatterAreaSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicScatterAreaSeriesComponent, _super);
    function IgcGeographicScatterAreaSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._triangulationStatusChanged = null;
        _this._triangulationStatusChanged_wrapped = null;
        return _this;
    }
    IgcGeographicScatterAreaSeriesComponent.prototype.createImplementation = function () {
        return new GeographicScatterAreaSeries();
    };
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicScatterAreaSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicScatterAreaSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicScatterAreaSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent = names;
            }
            return IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicScatterAreaSeriesComponent.register = function () {
        if (!IgcGeographicScatterAreaSeriesComponent._isElementRegistered) {
            IgcGeographicScatterAreaSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicScatterAreaSeriesComponent.htmlTagName, IgcGeographicScatterAreaSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.d9;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "colorMemberPath", {
        /**
         * The name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
        */
        get: function () {
            return this.i.u3;
        },
        set: function (v) {
            this.i.u3 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "colorScale", {
        /**
         * The ColorScale used to resolve the color values of points in the series.
        */
        get: function () {
            var r = this.i.uy;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcColorScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.uy = null : this.i.uy = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "actualColorScale", {
        /**
         * Gets actual color scale that is set on ColorScale property or default ColorScale
        */
        get: function () {
            var r = this.i.ux;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcColorScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.ux = null : this.i.ux = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicScatterAreaSeriesComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.colorScale && this.colorScale.name && this.colorScale.name == name) {
            return this.colorScale;
        }
        if (this.actualColorScale && this.actualColorScale.name && this.actualColorScale.name == name) {
            return this.actualColorScale;
        }
        return null;
    };
    IgcGeographicScatterAreaSeriesComponent.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.colorScale && this.colorScale._styling) {
            this.colorScale._styling(container, component, this);
        }
        if (this.actualColorScale && this.actualColorScale._styling) {
            this.actualColorScale._styling(container, component, this);
        }
        this._inStyling = false;
    };
    /**
     * Updates ActualColorScale properties using HostedSeries's ColorScale properties
    
    */
    IgcGeographicScatterAreaSeriesComponent.prototype.updateActualColorScale = function () {
        this.i.u8();
    };
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "triangulationStatusChanged", {
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get: function () {
            return this._triangulationStatusChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._triangulationStatusChanged_wrapped !== null) {
                this.i.triangulationStatusChanged = delegateRemove(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
                this._triangulationStatusChanged_wrapped = null;
                this._triangulationStatusChanged = null;
            }
            this._triangulationStatusChanged = ev;
            this._triangulationStatusChanged_wrapped = function (o, e) {
                var outerArgs = new IgcTriangulationStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeTriangulationStatusChanged) {
                    _this.beforeTriangulationStatusChanged(_this, outerArgs);
                }
                if (_this._triangulationStatusChanged) {
                    _this._triangulationStatusChanged(_this, outerArgs);
                }
            };
            this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent = null;
    IgcGeographicScatterAreaSeriesComponent.htmlTagName = "igc-geographic-scatter-area-series";
    IgcGeographicScatterAreaSeriesComponent._isElementRegistered = false;
    return IgcGeographicScatterAreaSeriesComponent;
}(IgcGeographicXYTriangulatingSeriesComponent));
export { IgcGeographicScatterAreaSeriesComponent };

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm5/lib/igc-geographic-scatter-area-series-component.js <==
import { __extends } from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcColorScaleComponent } from "igniteui-webcomponents-charts";
import { IgcTriangulationStatusEventArgs } from "igniteui-webcomponents-core";
import { IgcGeographicXYTriangulatingSeriesComponent } from "./igc-geographic-xy-triangulating-series-component";
import { GeographicScatterAreaSeries } from "./GeographicScatterAreaSeries";
import { getAllPropertyNames, toSpinal } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Series class which draws a colored 2D surface, in a geographic context, based on a triangulation of XY data with numeric values assigned to each point.
*/
var IgcGeographicScatterAreaSeriesComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcGeographicScatterAreaSeriesComponent, _super);
    function IgcGeographicScatterAreaSeriesComponent() {
        var _this = _super.call(this) || this;
        _this._triangulationStatusChanged = null;
        _this._triangulationStatusChanged_wrapped = null;
        return _this;
    }
    IgcGeographicScatterAreaSeriesComponent.prototype.createImplementation = function () {
        return new GeographicScatterAreaSeries();
    };
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicScatterAreaSeriesComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcGeographicScatterAreaSeriesComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent, "observedAttributes", {
        get: function () {
            if (IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent == null) {
                var names = getAllPropertyNames(IgcGeographicScatterAreaSeriesComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent = names;
            }
            return IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicScatterAreaSeriesComponent.register = function () {
        if (!IgcGeographicScatterAreaSeriesComponent._isElementRegistered) {
            IgcGeographicScatterAreaSeriesComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcGeographicScatterAreaSeriesComponent.htmlTagName, IgcGeographicScatterAreaSeriesComponent);
        }
    };
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "isArea", {
        /**
         * Gets whether the current series shows an area shape.
        */
        get: function () {
            return this.i.ev;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "colorMemberPath", {
        /**
         * The name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
        */
        get: function () {
            return this.i.x0;
        },
        set: function (v) {
            this.i.x0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "colorScale", {
        /**
         * The ColorScale used to resolve the color values of points in the series.
        */
        get: function () {
            var r = this.i.xv;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcColorScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xv = null : this.i.xv = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "actualColorScale", {
        /**
         * Gets actual color scale that is set on ColorScale property or default ColorScale
        */
        get: function () {
            var r = this.i.xu;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgcColorScaleComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.xu = null : this.i.xu = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicScatterAreaSeriesComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.colorScale && this.colorScale.name && this.colorScale.name == name) {
            return this.colorScale;
        }
        if (this.actualColorScale && this.actualColorScale.name && this.actualColorScale.name == name) {
            return this.actualColorScale;
        }
        return null;
    };
    IgcGeographicScatterAreaSeriesComponent.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.colorScale && this.colorScale._styling) {
            this.colorScale._styling(container, component, this);
        }
        if (this.actualColorScale && this.actualColorScale._styling) {
            this.actualColorScale._styling(container, component, this);
        }
        this._inStyling = false;
    };
    /**
     * Updates ActualColorScale properties using HostedSeries's ColorScale properties
    
    */
    IgcGeographicScatterAreaSeriesComponent.prototype.updateActualColorScale = function () {
        this.i.x5();
    };
    Object.defineProperty(IgcGeographicScatterAreaSeriesComponent.prototype, "triangulationStatusChanged", {
        /**
         * Raised when the status of an ongoing Triangulation has changed.
        */
        get: function () {
            return this._triangulationStatusChanged;
        },
        set: function (ev) {
            var _this = this;
            if (this._triangulationStatusChanged_wrapped !== null) {
                this.i.triangulationStatusChanged = delegateRemove(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
                this._triangulationStatusChanged_wrapped = null;
                this._triangulationStatusChanged = null;
            }
            this._triangulationStatusChanged = ev;
            this._triangulationStatusChanged_wrapped = function (o, e) {
                var outerArgs = new IgcTriangulationStatusEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeTriangulationStatusChanged) {
                    _this.beforeTriangulationStatusChanged(_this, outerArgs);
                }
                if (_this._triangulationStatusChanged) {
                    _this._triangulationStatusChanged(_this, outerArgs);
                }
            };
            this.i.triangulationStatusChanged = delegateCombine(this.i.triangulationStatusChanged, this._triangulationStatusChanged_wrapped);
            ;
        },
        enumerable: false,
        configurable: true
    });
    IgcGeographicScatterAreaSeriesComponent._observedAttributesIgcGeographicScatterAreaSeriesComponent = null;
    IgcGeographicScatterAreaSeriesComponent.htmlTagName = "igc-geographic-scatter-area-series";
    IgcGeographicScatterAreaSeriesComponent._isElementRegistered = false;
    return IgcGeographicScatterAreaSeriesComponent;
}(IgcGeographicXYTriangulatingSeriesComponent));
export { IgcGeographicScatterAreaSeriesComponent };
